screed -- short read sequence utils in Python.

The official central repository for screed is:

   https://github.com/dib-lab/screed

See http://readthedocs.org/docs/screed/en/latest/ for docs.

Issues are tracked at https://github.com/dib-lab/khmer/issues.

[![Build Status](https://travis-ci.org/dib-lab/screed.svg?branch=master)](https://travis-ci.org/dib-lab/screed)
